==> flink-runtime_2.12-1.8.1-sources.jar: org/apache/flink/runtime/resourcemanager/ResourceManagerServices.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.runtime.resourcemanager;

import org.apache.flink.runtime.clusterframework.types.ResourceProfile;

import java.util.UUID;
import java.util.concurrent.Executor;

/**
 * Interface which provides access to services of the ResourceManager.
 */
public interface ResourceManagerServices {

	/**
	 * Gets the current leader id assigned at the ResourceManager.
	 */
	UUID getLeaderID();

	/**
	 * Allocates a resource according to the resource profile.
	 */
	void allocateResource(ResourceProfile resourceProfile);

	/**
	 * Gets the async executor which executes outside of the main thread of the ResourceManager
	 */
	Executor getAsyncExecutor();

	/**
	 * Gets the executor which executes in the main thread of the ResourceManager
	 */
	Executor getMainThreadExecutor();

}

==> flink-runtime_2.12-1.13.0-sources.jar: org/apache/flink/runtime/resourcemanager/ResourceManagerServices.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.runtime.resourcemanager;

import org.apache.flink.runtime.clusterframework.types.ResourceProfile;

import java.util.UUID;
import java.util.concurrent.Executor;

/** Interface which provides access to services of the ResourceManager. */
public interface ResourceManagerServices {

    /** Gets the current leader id assigned at the ResourceManager. */
    UUID getLeaderID();

    /** Allocates a resource according to the resource profile. */
    void allocateResource(ResourceProfile resourceProfile);

    /** Gets the async executor which executes outside of the main thread of the ResourceManager */
    Executor getAsyncExecutor();

    /** Gets the executor which executes in the main thread of the ResourceManager */
    Executor getMainThreadExecutor();
}
